pub enum QueryMsg {
Config {},
Pair {
asset_infos: [AssetInfo; 2],
},
PairConfig {
asset_infos: [AssetInfo; 2],
},
Pairs {
start_after: Option<[AssetInfo; 2]>,
limit: Option<u32>,
},
PairsConfig {
start_after: Option<[AssetInfo; 2]>,
limit: Option<u32>,
},
FeeInfo {
asset_infos: [AssetInfo; 2],
},
}Expand description
Description
This structure describes the query messages of the contract.
Variants
Config
Config returns controls settings that specified in custom ConfigResponse structure
Pair
Pair returns a pair according to the specified parameters in asset_infos variable.
PairConfig
PairConfig returns a pair info and fee infor according to the specified parameters in asset_infos variable.
Pairs
Pairs returns an array of pairs with their configuration according to the specified parameters in start_after and limit variables.
PairsConfig
PairsConfig returns an array of pairs with their fee info according to the specified parameters in start_after and limit variables.
FeeInfo
FeeInfo returns settings that specified in custom FeeInfoResponse structure